def love():
    print('\n'.join(' '.join(*zip(*row)) for row in ([["*" if row==0 and col%3!=0 or row==1 and col%3==0 or row-col==2 or row+col==8 else " " for col in range(7)] for row in range(6)])))
    print('Guangyun & Jinze')



from setuptools import setup

setup(name='ljz_distributions',
      version='0.21',
      description='Gaussian and Binomial distributions',
      packages=['ljz_distributions'],
      author = 'Jinze Li',
      author_email = 'lijinze0704@gmail.com',
      zip_safe=False)
